@@ -67,7 +67,7 @@ try:
 except NameError:
     from sets import Set as set
 
-VERSION = "8.5.1"
+VERSION = "8.5.3"
 VERSION_BANNER = """dtrx version %s
 Copyright © 2006-2011 Brett Smith <brettcsmith@brettcsmith.org>
 Copyright © 2008 Peter Kelemen <Peter.Kelemen@gmail.com>
@@ -295,8 +295,13 @@ class BaseExtractor(object):
                         % (self.filename)
                     )
 
+    def send_stdout_to_dev_null(self):
+        return True
+
     def run_pipes(self, final_stdout=None):
-        has_output_target = True if final_stdout else False
+        has_output_target = (
+            True if final_stdout or self.send_stdout_to_dev_null() else False
+        )
         if not self.pipes:
             return
         elif final_stdout is None:
@@ -713,6 +718,9 @@ class SevenExtractor(NoPipeExtractor):
                 yield line[fn_index:]
         self.archive.close()
 
+    def send_stdout_to_dev_null(self):
+        return False
+
     def timeout_check(self, pipe):
         nbs = NonblockingRead(pipe.stdout)
         errs = nbs.readlines()
